@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=undefined-variable
 """Module with data plugins to represent pseudo potentials."""
+from .jthxml import *
 from .pseudo import *
 from .psf import *
 from .psml import *
 from .psp8 import *
 from .upf import *
 
-__all__ = (pseudo.__all__ + psf.__all__ + psml.__all__ + psp8.__all__ + upf.__all__)
+__all__ = (jthxml.__all__ + pseudo.__all__ + psf.__all__ + psml.__all__ + psp8.__all__ + upf.__all__)
