@@ -3,7 +3,7 @@
 """Tests for the command `aiida-pseudo show`."""
 from aiida.orm import Group
 from aiida_pseudo.cli import cmd_show
-from aiida_pseudo.groups.family import PseudoPotentialFamily, UpfFamily
+from aiida_pseudo.groups.family import PseudoPotentialFamily
 
 
 def test_show(clear_db, run_cli_command, get_pseudo_family):
@@ -19,11 +19,9 @@ def test_show(clear_db, run_cli_command, get_pseudo_family):
 def test_show_argument_type(clear_db, run_cli_command, get_pseudo_family):
     """Test that `aiida-pseudo show` only accepts instances of `PseudoPotentialFamily` or subclasses as argument."""
     pseudo_family = get_pseudo_family(label='pseudo-family', cls=PseudoPotentialFamily)
-    upf_family = get_pseudo_family(label='upf-family', cls=UpfFamily)
     normal_group = Group('normal-group').store()
 
     run_cli_command(cmd_show, [pseudo_family.label])
-    run_cli_command(cmd_show, [upf_family.label])
     run_cli_command(cmd_show, [normal_group.label], raises=SystemExit)
 
 
